# -*- coding: utf-8 -*-
import gtk, sys, os

#-------------------------------------------------------------------
# D&D
DND_TARGET_COLOR = 100
DND_TARGET_BGIMAGE = 101
DND_TARGET_RESET_BG = 102
DND_TARGET_URI_LIST = 103
DND_TARGET_MOZ_URL = 104
DND_TARGET_UTF8_STRING = 105
DND_TARGET_COMPOUND_TEXT = 106
DND_TARGET_TEXT_PLAIN = 107
DND_TARGET_STRING = 108
DND_TARGET_TEXT_PLAIN = 109
DND_TARGET_TEXT = 110

# drag and drop target tables, it from terminal-screen.c in
# gnome-terminal.
DND_TARGET_TABLE = [
	( "application/x-color", 0, DND_TARGET_COLOR ),
	( "property/bgimage",    0, DND_TARGET_BGIMAGE ),
	( "x-special/gnome-reset-background", 0, DND_TARGET_RESET_BG ),
	( "text/uri-list",  0, DND_TARGET_URI_LIST ),
	( "text/x-moz-url",  0, DND_TARGET_MOZ_URL ),
	( "UTF8_STRING", 0, DND_TARGET_UTF8_STRING ),
	( "COMPOUND_TEXT", 0, DND_TARGET_COMPOUND_TEXT ),
	( "TEXT", 0, DND_TARGET_TEXT ),
	( "STRING",     0, DND_TARGET_STRING ),
	( "text/plain", 0, DND_TARGET_TEXT_PLAIN )
]

#-------------------------------------------------------------------
# GConf
# GLOBAL configuration values.
GLOBAL_FONT_SYSTEM_DEFAULT		= "/desktop/gnome/interface/monospace_font_name"

# LOCAL configuration values.
LOCAL_ROOT									=	"/apps/vee/"
SCHEMA_ROOT									=	"/schemas/apps/vee/"
SCHEMA_FILE									=	"vee.schema"

SCHEMA = {
	"use-system-default-font" : {
		"key" : LOCAL_ROOT + "use_system_default_font",
		"schema" : SCHEMA_ROOT + "use_system_default_font",
		"type" : "bool",
		"default" : True,
	},

	"font-vim" : {
		"key" : LOCAL_ROOT + "vim_font",
		"schema" : SCHEMA_ROOT + "vim_font",
		"type" : "string",
		"default" : "Monospace 16",
	},

	"font-terminal" : {
		"key" : LOCAL_ROOT + "terminal_font",
		"schema" : SCHEMA_ROOT + "terminal_font",
		"type" : "string",
		"default" : "Monospace 16",
	},

	"show-menubar" : {
		"key" : LOCAL_ROOT + "show_menubar",
		"schema" : SCHEMA_ROOT + "show_menubar",
		"type" : "bool",
		"default" : True,
	},

	"show-toolbar" : {
		"key" : LOCAL_ROOT + "show_toolbar",
		"schema" : SCHEMA_ROOT + "show_toolbar",
		"type" : "bool",
		"default" : True,
	},

	"command-vim" : {
		"key" : LOCAL_ROOT + "vim_command",
		"schema" : SCHEMA_ROOT + "vim_command",
		"type" : "string",
		"default" : "vim",
	},

	"command-terminal" : {
		"key" : LOCAL_ROOT + "terminal_command",
		"schema" : SCHEMA_ROOT + "terminal_command",
		"type" : "string",
		"default" : "bash",
	},

	"color-foreground" : {
		"key" : LOCAL_ROOT + "foreground_color",
		"schema" : SCHEMA_ROOT + "foreground_color",
		"type" : "int_list",
		"default" : [65535,65535,65535,0],
	},

	"color-background" : {
		"key" : LOCAL_ROOT + "background_color",
		"schema" : SCHEMA_ROOT + "background_color",
		"type" : "int_list",
		"default" : [0,0,0,0],
	},

	"latest-window-geometry" : {
		"key" : LOCAL_ROOT + "latest_window_geometry",
		"schema" : SCHEMA_ROOT + "latest_window_geometry",
		"type" : "string",
		"default" : "700,800",
	},
}

import GConf, gconf

def verify () :
	"""
	Check whether key and it's type is correct or not, if not insert
	new schema.
	"""

	try :
		GCONF_CLIENT = GConf.Client()
		GCONF_CLIENT.set_path(LOCAL_ROOT)
	except :
		install_schema()
	else :
		if not isinstance(GCONF_CLIENT.CLIENT.get_schema( \
				SCHEMA["use-system-default-font"]["schema"]), gconf.Schema) :
			install_schema()

def install_schema () :

	import os, time

	a, b, c = \
		os.popen3("gconftool-2 --install-schema-file=%s" % SCHEMA_FILE)

	if len(c.readlines()) > 0 :
		print ">> Failed to install Schema file."

		return

	print ">> Install Schema file."
	print ""

	time.sleep(2)

	return True

#-------------------------------------------------------------------
# Keyboard shorcut
KEYBOARD_SHORTCUT_GLOBAL = ( \
	"focus-external-command-entry",
)

KEYBOARD_SHORTCUT_WHEN_HIDE_MENUBAR = ( \
	"next-tab",
	"prev-tab",
	"increase-font",
	"decrease-font",
	"insert-gvim",
	"insert-vim",
	"insert-terminal",
	"fileselect-dialog",
	"mainwindow-quit",
	"insert-external-command",
)

LIST_KEYBOARD_SHORTCUT = {
	"next-tab" : ("<Control>Page_Up" , "self.ac_next_tab "),
	"prev-tab" : ("<Control>Page_Down" , "self.ac_previous_tab"),

	"increase-font" : ("<Control>equal" , "self.ac_font_increase "),
	"decrease-font" : ("<Control>minus" , "self.ac_font_decrease "),

	"insert-gvim" : ("<Control><Shift>G" , "self.ac_insert_gvim "),
	"insert-vim" : ("<Control><Shift>V" , "self.ac_insert_vim "),
	"insert-terminal" : ("<Control><Shift>Z" , "self.ac_insert_terminal "),
	"insert-external-command" : \
		("<Control><Shift>L" , "self.ac_focus_on_external_command"),

	"fileselect-dialog" : ("<Control><Shift>O" , "self.ac_fileSelectionDialog "),
	"mainwindow-quit" : ("<Control>Q" , "gtk.main_quit"),

	"focus-external-command-entry" : \
		("<Control><Shift>L", "self.ac_focus_on_external_command"),
}

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "Conf.py"


